@@ -3,6 +3,7 @@
 // Distributed under the terms of the Modified BSD License.
 
 // Modified from jupyterlab/packages/completer/src/contextconnector.ts
+import { Cell } from '@jupyterlab/cells';
 
 import { CodeEditor } from '@jupyterlab/codeeditor';
 import { DataConnector } from '@jupyterlab/statedb';
@@ -73,6 +74,49 @@ export class CustomConnector extends DataConnector<
   private _editor: CodeEditor.IEditor | null;
 }
 
+interface ITextData {
+  prompt: string;
+  suffix: string;
+}
+
+function processCellStringData(
+  cells: ReadonlyArray<Cell>,
+  index: number,
+  cursor: CodeEditor.IPosition
+): ITextData {
+  // get all cells up to index
+  const cellsUpToIndex = cells.slice(0, index);
+
+  // get all cells after index
+  const cellsAfterIndex = cells.slice(index + 1, cells.length);
+
+  const cellTextBefore = cellsUpToIndex
+    .map(cell => cell.model.value.text)
+    .join('\n');
+
+  const cellTextCurrent = cells[index].model.value.text;
+
+  const cellTextAfter = cellsAfterIndex
+    .map(cell => cell.model.value.text)
+    .join('\n');
+
+  let beforeText: string = cellTextBefore;
+  const afterTextSplit = cellTextCurrent.split('\n');
+  beforeText += '\n\n' + afterTextSplit.splice(0, cursor.line).join('\n');
+  const cursorText = afterTextSplit.splice(0, 1)[0];
+  beforeText += '\n' + cursorText.slice(0, cursor.column);
+  const afterText: string =
+    cursorText.slice(cursor.column, cursorText.length) +
+    '\n' +
+    afterTextSplit.join('\n') +
+    cellTextAfter;
+
+  return {
+    prompt: beforeText,
+    suffix: afterText
+  };
+}
+
 /**
  * A namespace for custom connector statics.
  */
@@ -116,22 +160,7 @@ namespace Private {
     // @ts-ignore
     const index = cells.indexOf(panel.content.activeCell);
 
-    // get all cells up to index
-    const cellsUpToIndex = cells.slice(0, index + 1);
-
-    // get all cells after index
-    const cellsAfterIndex = cells.slice(index + 1);
-
-    // append cellsUpToIndex to cellsAfterIndex
-    const cellsToComplete = cellsAfterIndex.concat(cellsUpToIndex);
-
-    // get source code of all cells
-    const sources = cellsToComplete.map(cell => cell.model.value.text);
-
-    // concatenate sources, this will be used as a prompt
-    const prompt = sources.join('\n\n');
-
-    console.log('prompt: ' + prompt);
+    const data = processCellStringData(cells, index, cursor);
 
     // Get all text in the editor
     //const activeCellText = editor.model.value.text;
@@ -141,7 +170,7 @@ namespace Private {
 
     // Send to handler
     // TODO: rename this line to prompt
-    const dataToSend = { line: prompt, domain, apiKey, flag };
+    const dataToSend = { data, domain, apiKey, flag };
 
     // POST request
     let reply = requestAPI<any>('AUTOCOMPLETE', {
